@@ -6,7 +6,9 @@ use warnings FATAL => 'all';
 use OxdPackages::OxdConfig;
 use OxdPackages::OxdRegister;
 use OxdPackages::OxdSetupClient;
+use OxdPackages::OxdRemove;
 use OxdPackages::GetClientToken;
+use OxdPackages::IntrospectAccessToken;
 use OxdPackages::UpdateRegistration;
 use OxdPackages::GetAuthorizationUrl;
 use OxdPackages::GetTokenByCode;
@@ -15,6 +17,7 @@ use OxdPackages::GetUserInfo;
 use OxdPackages::OxdLogout;
 use OxdPackages::UmaRsProtect;
 use OxdPackages::UmaRpGetRpt;
+use OxdPackages::UmaIntrospectRpt;
 use OxdPackages::UmaRsCheckAccess;
 use OxdPackages::UmaRpGetClaimsGatheringUrl;
 
@@ -24,11 +27,11 @@ OxdPerlModule - The great new OxdPerlModule!
 
 =head1 VERSION
 
-Version 0.02
+Version 0.01
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.01';
 
 
 =head1 SYNOPSIS
@@ -65,12 +68,12 @@ sub function2 {
 
 =head1 AUTHOR
 
-Sobhan Panda, C<< <sobhan at centroxy.com> >>
+Gaurav Chhabra, C<< <gaurav.chhabra6785 at gmail.com> >>
 
 =head1 BUGS
 
-Please report any bugs or feature requests to C<bug-oxdperl at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=oxdperl>.  I will be notified, and then you'll
+Please report any bugs or feature requests to C<bug-oxdperlmodule at rt.cpan.org>, or through
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=OxdPerlModule>.  I will be notified, and then you'll
 automatically be notified of progress on your bug as I make changes.
 
 
@@ -89,19 +92,19 @@ You can also look for information at:
 
 =item * RT: CPAN's request tracker (report bugs here)
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=oxdperl>
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=OxdPerlModule>
 
 =item * AnnoCPAN: Annotated CPAN documentation
 
-L<http://annocpan.org/dist/oxdperl>
+L<http://annocpan.org/dist/OxdPerlModule>
 
 =item * CPAN Ratings
 
-L<http://cpanratings.perl.org/d/oxdperl>
+L<http://cpanratings.perl.org/d/OxdPerlModule>
 
 =item * Search CPAN
 
-L<http://search.cpan.org/dist/oxdperl/>
+L<http://search.cpan.org/dist/OxdPerlModule/>
 
 =back
 
@@ -111,7 +114,7 @@ L<http://search.cpan.org/dist/oxdperl/>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2017 Gluu.
+Copyright 2017 Gaurav Chhabra.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the the Artistic License (2.0). You may obtain a
